{ config, pkgs, ... }:

{

  home = {
    username = "aaronh";
    homeDirectory = "/home/aaronh";
    stateVersion = "24.11";
  };

  home.packages = with pkgs; [
    deja-dup
    libreoffice-fresh
    signal-desktop

  ];

  programs.bash = {
    enable = true;
    shellAliases = {
      nix-generations = "sudo nix-env -p /nix/var/nix/profiles/system --list-generations";
      nix-upgrade = "sudo nixos-rebuild switch --upgrade";
      nix-full-upgrade = "sudo nix flake update --flake /etc/nixos && sudo nixos-rebuild switch --upgrade";
    };
    #bashrcExtra = "eval `ssh-agent`";
  };

  programs.git = {
    enable = true;
    lfs.enable = true;
    userName = "Aaron Honeycutt";
    userEmail = "aaronhoneycutt@protonmail.com";
    aliases = {
       undo = "reset HEAD~1 --mixed";
       amend = "commit -a --amend";
       feature = "commit -m feat: -m new-feature";
       fix = "commit -m fix: -m issue#";
    };
    extraConfig = {
      color = {
         ui = "auto";
      };
      color.status = {
         added = "green bold";
         changed = "yellow bold";
         untracked = "red bold";
      };
      push = {
         autoSetupRemote = "true";
      };
      init = {
          defaultBranch = "main";
      };
    };
  };

  programs.keychain = {
    enable = true;
    keys = [
      "protonmail"
    ];
  };

  programs.helix = {
    enable = true;
    settings = {
       theme = "ferra";
    };
  };

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

}
